import java.awt.event.*;
import javax.swing.*;

/**
 * Echo.java
 * 
 * Provides a listener that takes entry from a textfield and prints it to
 * the console.
 * 
 * Based on Pohl and McDowell, 'Java by Dissection' pp 276-277.
 * 
 * This is an extended example which illustrates exception handling.
 * 
 * Simon Parsons
 * 22nd October 2012
 *
 */
class Echo implements ActionListener{
	public void actionPerformed(ActionEvent e){
		// Don't miss the explicit cast on the righthand side
		// of the assignment.
		JTextField source = (JTextField)e.getSource();
		String text = source.getText();
		System.out.println(text);
		
		// Here we think there might be an exception.
		try{
			Double d = Double.valueOf(text.trim());
			double d2 = d.doubleValue();
			System.out.println(d2/2);
		}
		// Here we make an attempt at catching the exception. This
		// will only execute if the exception matches the argument.
		catch(java.lang.NumberFormatException e1){
			System.out.println("Enter a number!");
		}
		// This is executed after a try (and any associated catch).
		finally{
			System.out.println("Please go again!");
		}
	}
}